#[non_exhaustive]pub enum ContentStatus {
Draft,
Pending,
Active,
Paused,
DeletedByUser,
DeletedByCompany,
}Expand description
The status of a posting.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Draft
The posting has not yet been submitted by the user to go live.
Pending
The user has submitted the posting but has not gone live.
This may be because the posting needs to be reviewed, the user needs to add payment details, or because of some other processes within your business.
Active
The posting is live and active on your site. Other users can see the posting.
Paused
The posting has been paused by the user and may return back to ContentStatus::Active at a later date.
DeletedByUser
The posting has been deleted or archived by the user.
DeletedByCompany
The posting has been deleted or archived by your company due to violation of terms of service or other policies.