CreditPoint

Struct CreditPoint 

pub struct CreditPoint {
    pub amount: i64,
    pub credit_point_type: String,
    pub extra: Option<Value>,
}
Monetary and non-monetary rewards.

(e.g. in-game currency, stored account value, MBs storage, frequent flyer miles, etc) associated with a promotion. Credit points are usually used for promotions that apply at the account level. The value must be a nested JSON object populated with the appropriate information to describe the credit_point. All values are required.

A credit_point is an object that gets included as part of promotion object. Learn more about Promotions.

Fields

amount: i64

The amount of credits the promotion is worth.

credit_point_type: String

The type of credit point. Particularly useful if you have multiple types of credit points that you give out. Enables us to distinguish amongst them to find patterns (e.g. days of free service, karma, frequent flyer miles, MBs of storage, etc.).

extra: Option<Value>

Any extra non-reserved fields to be recorded with the credit point.