MessageProperties

Struct MessageProperties 

pub struct MessageProperties {
    pub subject: Option<String>,
    pub body: Option<String>,
    pub contact_email: Option<String>,
    pub root_content_id: Option<String>,
    pub recipient_user_ids: Option<Vec<String>>,
    pub images: Option<Vec<Image>>,
    pub extra: Option<Value>,
}
Used to represent a message exchanged between users of your service.

https://sift.com/developers/docs/curl/events-api/reserved-events/create-content/message

Fields

subject: Option<String>

The user-supplied subject of the message.

body: Option<String>

The text content of the message.

contact_email: Option<String>

The email address associated with the message sender.

root_content_id: Option<String>

The content id in the context of which the messages is sent.

For example, this would be the job listing being responded to.

recipient_user_ids: Option<Vec<String>>

The user ids of the recipients of the message.

images: Option<Vec<Image>>

The list of images shared by the user with their message.

It includes images pasted inline or attached separately.

extra: Option<Value>

Any extra non-reserved fields to be recorded with the message.