UpdatePasswordProperties

Struct UpdatePasswordProperties 

pub struct UpdatePasswordProperties {
    pub browser: Option<Browser>,
    pub app: Option<App>,
    pub brand_name: Option<String>,
    pub site_country: Option<String>,
    pub site_domain: Option<String>,
    pub extra: Option<Value>,
}
Fields

browser: Option<Browser>

The user agent of the browser that is used to update the password.

Represented by the Browser object. Use this field if the client is a browser.

Note: cannot be used in conjunction with app.

app: Option<App>

The details of the app, os, and device that is used to update the password.

Represented by the App struct. Use this field if the client is an app.

Note: cannot be used in conjunction with browser.

brand_name: Option<String>

Name of the brand of product or service being purchased.

site_country: Option<String>

Country the company is providing service from. Use ISO-3166 country code.

site_domain: Option<String>

Domain being interfaced with. Use fully qualified domain name.

extra: Option<Value>

Any extra non-reserved fields to be recorded with the event.