pub struct ResendRequest {
pub user_id: String,
pub verified_event: Option<VerifiedEvent>,
pub verified_entity_id: Option<String>,
}Expand description
Resend verification request data
Fields
user_id: StringUser ID of user being verified.
e.g. johndoe123
verified_event: Option<VerifiedEvent>This will be the event type that triggered the verification
verified_entity_id: Option<String>The ID of the entity impacted by the event being verified.