pub struct WebhookRequest {
pub payload_type: PayloadType,
pub status: Status,
pub url: String,
pub enabled_events: Vec<EnabledEvent>,
pub name: Option<String>,
pub description: Option<String>,
}Expand description
Options when creating a new Webhook.
See https://sift.com/developers/docs/curl/webhooks-api/create for examples.
Fields
payload_type: PayloadTypeThe type of webhook payload
status: StatusThe webhook status.
url: StringThe URL of the webhook endpoint.
This must be HTTPS.
enabled_events: Vec<EnabledEvent>The list of events to enable for this endpoint.
These correspond to the Reserved Events in the Events API.
name: Option<String>A name you specify for this webhook.
description: Option<String>A description about what the webhook is used for.